@@ -1,5 +1,4 @@
 use httpmock::prelude::*;
-use isahc::Body;
 use std::io::Read;
 
 #[test]
@@ -15,16 +14,18 @@ fn binary_body_test() {
     });
 
     // Act
-    let mut response = isahc::get(server.url("/hello")).unwrap();
+    let mut response = reqwest::blocking::get(server.url("/hello")).unwrap();
 
     // Assert
     m.assert();
     assert_eq!(response.status(), 200);
-    assert_eq!(body_to_vec(response.body_mut()), binary_content.to_vec());
+    assert_eq!(body_to_vec(&mut response), binary_content.to_vec());
 }
 
-fn body_to_vec(body: &mut Body) -> Vec<u8> {
+fn body_to_vec(response: &mut reqwest::blocking::Response) -> Vec<u8> {
     let mut buf: Vec<u8> = Vec::new();
-    body.read_to_end(&mut buf).expect("Cannot read from body");
+    response
+        .read_to_end(&mut buf)
+        .expect("Cannot read from body");
     buf
 }
