@@ -1,5 +1,4 @@
 use httpmock::prelude::*;
-use isahc::get;
 use std::time::{Duration, SystemTime};
 
 #[test]
@@ -15,11 +14,11 @@ fn delay_test() {
         then.status(200).delay(delay);
     });
 
-    // Act: Send the HTTP request
-    let response = get(server.url("/delay")).unwrap();
+    // Act: Send the HTTP request using reqwest
+    let response = reqwest::blocking::get(server.url("/delay")).unwrap();
 
     // Assert
     mock.assert();
     assert_eq!(response.status(), 200);
-    assert_eq!(start_time.elapsed().unwrap() > delay, true);
+    assert!(start_time.elapsed().unwrap() > delay);
 }
