@@ -1,5 +1,4 @@
 use httpmock::prelude::*;
-use isahc::get;
 
 #[test]
 fn explicit_delete_mock_test() {
@@ -7,17 +6,14 @@ fn explicit_delete_mock_test() {
     let server = MockServer::start();
 
     let mut m = server.mock(|when, then| {
-        when.method(GET).path("/health");
+        when.method("GET").path("/health");
         then.status(205);
     });
 
-    // Act: Send the HTTP request
-    let response = get(&format!(
-        "http://{}:{}/health",
-        server.host(),
-        server.port()
-    ))
-    .unwrap();
+    // Act: Send the HTTP request using reqwest
+    let response =
+        reqwest::blocking::get(format!("http://{}:{}/health", server.host(), server.port()))
+            .unwrap();
 
     // Assert
     m.assert();
@@ -26,8 +22,8 @@ fn explicit_delete_mock_test() {
     // Delete the mock and send the request again
     m.delete();
 
-    let response = get(&format!("http://{}/health", server.address())).unwrap();
+    let response = reqwest::blocking::get(format!("http://{}/health", server.address())).unwrap();
 
-    // Assert that the request failed, because the mock has been deleted
+    // Assert that the request failed because the mock has been deleted
     assert_eq!(response.status(), 404);
 }
